#ifndef MESSAGECODER_H
#define MESSAGECODER_H

#include"candatatype.h"
#include "canbus.h"

namespace robot {
namespace canbus {

class MessageCoder
{
private:
    //字符串反转
    static void CharReverse(unsigned char *s, int n);

    //执行机构使能请求--数据解析
    static void CanMsgAnalyseID_5F2(unsigned char * ucData, T_ACTUATOR_ENABLE_REQUEST *tActEnableReq);

    //转向执行机构控制命令--数据解析
    static void CanMsgAnalyseID_5F5(unsigned char *ucData, T_STR_ACT_CTR_REQ *tStrActCtrReq);

    //车辆状态1--数据解析
    static void CanMsgAnalyseID_6F1(unsigned char *ucData, T_VEHICLE_STATUS_1 *tVehicleStat1);

    //车辆状态2--数据解析
    static void CanMsgAnalyseID_6F2(unsigned char *ucData, T_VEHICLE_STATUS_2 *tVehicleStat2);

    //车辆状态3--数据解析
    static void CanMsgAnalyseID_6F3(unsigned char *ucData, T_VEHICLE_STATUS_3 *tVehicleStat3);

    //工控机状态--数据解析
    static void CanMsgAnalyseID_6F4(unsigned char *ucData, T_COMPUTER_STATUS *tComputerStat);

    //机器人执行机构实际位置--数据解析
    static void CanMsgAnalyseID_6E0(unsigned char *ucData, T_RBT_ACT_PSNG *tRbtActPsng);

    //踏板学习位置反馈--数据解析
    static void CanMsgAnalyseID_6E1(unsigned char *ucData, T_ACC_BRK_PSNG *tAccBrkPsng);

    //转向学习位置反馈--数据解析
    static void CanMsgAnalyseID_6E2(unsigned char *ucData, T_STR_LRN_PSNG *tStrLrnPsng);

    //档位学习位置反馈1--数据解析
    static void CanMsgAnalyseID_6E3(unsigned char *ucData, T_SFT_LRN_PST_1 *tSftLrnPst1);

    //控制器上电状态--数据解析
    static void CanMsgAnalyseID_6E4(unsigned char *ucData, T_CTR_POW_STATUS *tCtrPowStatus);

    //执行机构使能状态--数据解析
    static void CanMsgAnalyseID_6E5(unsigned char *ucData, T_ACT_ENABLE_STATUS *tActEnableStatus);

    //油门控制状态反馈--数据解析
    static void CanMsgAnalyseID_6E6(unsigned char *ucData, T_ACC_CTR_STATUS *tAccCtrStatus);

    //制动踏板控制状态反馈--数据解析
    static void CanMsgAnalyseID_6E7(unsigned char *ucData, T_BRK_CTR_STATUS *tBrkCtrStatus);

    //离合踏板控制状态反馈--数据解析
    static void CanMsgAnalyseID_6E8(unsigned char *ucData, T_CLCH_CTR_STATUS *tClchCtrStatus);

    //转向控制状态反馈--数据解析
    static void CanMsgAnalyseID_6E9(unsigned char *ucData, T_STR_STATUS *tStrStatus);

    //档位控制状态反馈--数据解析
    static void CanMsgAnalyseID_6EA(unsigned char *ucData, T_SFT_STATUS *tSftStatus);

    //系统运行状态参数反馈1--数据解析
    static void CanMsgAnalyseID_6EB(unsigned char *ucData, T_SYS_INFO_1 *tSysInfo1);

    //系统运行状态参数反馈2--数据解析
    static void CanMsgAnalyseID_6ED(unsigned char *ucData, T_SYS_INFO_2 *tSysInfo2);

    //系统学习状态反馈--数据解析
    static void CanMsgAnalyseID_6EE(unsigned char *ucData, T_SYS_LRN *tSysLrn);

    //档位学习位置反馈2--数据解析
    static void CanMsgAnalyseID_6EF(unsigned char *ucData, T_SFT_LRN_PST_2 *tSFtLrnPst2);

    //系统监控状态反馈--数据解析
    static void CanMsgAnalyseID_6D0(unsigned char *ucData, T_SYS_MONITOR *tSysMonitor);

    //系统报警--数据解析
    static void CanMsgAnalyseID_6D1(unsigned char *ucData, T_SYS_ERR *tSysErr);

    //方向盘位置时间控制请求--数据解析
    static void CanMsgAnalyseID_6D7(unsigned char *ucData, T_STEER_PST_TIME_REQ *tSteerPstTimeReq);

    //Estop系统信息--数据解析
    static void CanMsgAnalyseID_2E0(unsigned char *ucData, T_ESTOP_INFO *tEstopInfo);

    //Estop故障码--数据解析
    static void CanMsgAnalyseID_2E1(unsigned char *ucData, T_ESTOP_ERR *tEstopErr);

    //油门(acc)、制动(brk)、挡位(sft)X、挡位(sft)Y、转向(str)电机报警--数据解析
    static void CanMsgAnalyseErr(unsigned char *ucData, T_MOT_CTR_ERR *tMotCtrErr);

    //OBD实际油门踏板行程--数据解析
    static void OBDAnalyseID_1A1(unsigned char *ucData, T_OBD_ACC_PSNG *tOBDAccPsng);

    //OBD实际制动踏板行程--数据解析
    static void OBDAnalyseID_0F1(unsigned char *ucData, T_OBD_BRK_PSNG *tOBDBrkPsng);

    //OBD实际挡位--数据解析
    static void OBDAnalyseID_135(unsigned char *ucData, T_OBD_SFT_PSNG *tOBDSftPsng);

    //OBD车辆手刹状态--数据解析
    static void OBDAnalyseID_1F1(unsigned char *ucData, T_OBD_VEH_BRK_STAT *tOBDVehBrkStat);

    //OBD实际车辆启动状态--数据解析
    static void OBDAnalyseID_121(unsigned char *ucData, T_OBD_VEH_SW_STAT *tOBDVehSwStat);

    //OBD实际方向盘转角--数据解析
    static void OBDAnalyseID_1E5(unsigned char *ucData, T_OBD_STR_ANG *tOBDStrAng);

    //OBD实际发动机转速--数据解析
    static void OBDAnalyseID_0C9(unsigned char *ucData, T_OBD_ENG_SPD *tOBDEngSpd);

    //控制器上电命令--数据组包
    static void CanMsgPackageID_5F1(T_POWER_ON_REQUEST *tPowOnReq, TPCANMsg *tCanMsg);

    //执行机构使能请求--数据组包
    static void CanMsgPackageID_5F2(T_ACTUATOR_ENABLE_REQUEST *tActEnableReq, TPCANMsg *tCanMsg);

    //学习模式请求确认--数据组包
    static void CanMsgPackageID_5F3(T_LEARN_MODE_REQUEST *tLearnMdReq, TPCANMsg *tCanMsg);

    //踏板执行机构控制命令--数据组包
    static void CanMsgPackageID_5F4(T_PEDAL_ACT_CTR_REQ *tPedalActCtrReq,TPCANMsg *tCanMsg);

    //转向执行机构控制命令--数据组包
    static void CanMsgPackageID_5F5(T_STR_ACT_CTR_REQ *tStrActCtrReq, TPCANMsg *tCanMsg);

    //档位执行机构控制命令--数据组包
    static void CanMsgPackageID_5F6(T_SFT_ACT_CTR_REQ *tSftActCtrReq,TPCANMsg *tCanMsg);

    //机器人自检控制命令--数据组包
    static void CanMsgPackageID_5F7(T_RBT_SLF_CHK_CTR_REQ *tRbtSlfChkCtrRq,TPCANMsg *tCanMsg);

    //机器人手动控制命令--数据组包
    static void CanMsgPackageID_5F8(T_RBT_DRIVER_CTR *tRbtDriverCtr, TPCANMsg *tCanMsg);

    //设备管理--数据组包
    static void CanMsgPackageID_5F9(T_RBT_MANAGER *tRbtManager, TPCANMsg *tCanMsg);

    //上位机监控--数据组包
    static void CanMsgPackageID_5FA(T_ICU_MONITOR *tIcuMonitor, TPCANMsg *tCanMsg);

    //执行机构加速度控制请求--数据组包
    static void CanMsgPackageID_5FB(T_ACT_ACC_CTR_REQ *tActAccCtrReq, TPCANMsg *tCanMsg);

    //执行机构限值设置--数据组包
    static void CanMsgPackageID_5FC(T_ACT_CTR_LIMT *tActCtrLimt, TPCANMsg *tCanMsg);

    //力矩保护设置--数据组包
    static void CanMsgPackageID_5FD(T_TRQ_PRTCT_STP *tTrqPrtctSetp, TPCANMsg *tCanMsg);

    //制动机构力时间控制设置--数据组包
    static void CanMsgPackageID_5FE(T_BRK_FRC_CTR_STP *tBrkFrcCtrStp, TPCANMsg *tCanMsg);

    //转向三角波--数据组包
    static void CanMsgPackageID_7F3(T_STR_TRNGL_LN_CTR *tStrTrnglLnCtr, TPCANMsg *tCanMsg);

    //转向正弦控制--数据组包
    static void CanMsgPackageID_7F4(T_STR_SIN_CTR *tStrSinCtr, TPCANMsg *tCanMsg);

    //油门机构位置时间控制--数据组包
    static void CanMsgPackageID_7F5(T_ACC_PSTN_CTR_STP *tAccPstnCtrStp, TPCANMsg *tCanMsg);

    //方向盘位置时间序列控制--数据组包
    static void CanMsgPackageID_7F6(T_STR_PSTN_TM_CTR *tStrPstnTmCtr, TPCANMsg *tCanMsg);

    //车辆一键启动--数据组包
    static void CanMsgPackageID_7F7(T_VEHICLE_START *tVehicleStart,TPCANMsg *tCanMsg);

    //车辆状态1--数据组包
    static void CanMsgPackageID_6F1(T_VEHICLE_STATUS_1 *tVehicleStatus1, TPCANMsg *tCanMsg);

    //车辆状态2--数据组包
    static void CanMsgPackageID_6F2(T_VEHICLE_STATUS_2 *tVehicleStatus2, TPCANMsg *tCanMsg);

    //车辆状态3--数据组包
    static void CanMsgPackageID_6F3(T_VEHICLE_STATUS_3 *tVehicleStatus3, TPCANMsg *tCanMsg);
public:
    //数据解析
    static void * CanMsgAnalyse(int id, unsigned char * ucData);
    //数据组包
    static void CanMsgPackage(void *p,int id, TPCANMsg *tCanMsg);

    static void ConvertUnCharToStr(char *str,unsigned char *UnChar,int ucLen);

};
}// namespace canbus
}// namespace robot

#endif // MESSAGECODER_H
