/******************************************************************************
 * Copyright 2020 The siasun Transport Authors. All Rights Reserved.
 * Author:mds。
 *
 * Licensed under the Apache License, Version 1.0 (the "License");
 *****************************************************************************/

#ifndef ROBOT_COMMON_SQLITE3HELPER_H_
#define ROBOT_COMMON_SQLITE3HELPER_H_
#include <stdio.h>
#include <string.h>
#include "sqlite3.h"
#include "gloghelper.h"
/**
 * @namespace robot::common
 * @brief robot::common
 */
namespace robot {
namespace common {

// 封装返回值
typedef struct QureyResult
{
  int n_row;
  int n_column;
  int n_index;
  char** p_result;

  QureyResult(int row, int column, char**p) {
    n_row = row;
    n_column = column;
    p_result = NULL;
    n_index = 0;
    if (n_row > 0)
      p_result = p;
  } // end QueryResult

  ~QureyResult() {
    if (p_result)
      sqlite3_free_table(p_result);
  }

  bool next() {
    if (n_index == 0) {
      if (n_row > 0) {
        ++n_index;
        return true;
      }
      else
        return false;
    }
    else {
      if ((n_row * n_column) >= ((n_index + 1) * n_column)) {
        ++n_index;
        return true;
      }
      else
        return false;
    } // end else
  }

  char* value(char *pColumnName) {
    int index = n_index * n_column;
    for (int i = 0; i < n_column; ++i) {
      if (strcmp(pColumnName, p_result[i]) == 0)
        return p_result[index];
      ++index;
    }
    return NULL;
  }
} query_result_t;

class Sqlite3helper
{
public:
  Sqlite3helper();

  // 操作：打开sqlite数据库
  // 前置条件：dbname 数据库名称
  // 后置条件：sqlite3指针
  sqlite3* open(const char *dbname);

  // 判断表是否存在
  // @param tableName 身份证号
  // @result -1失败 0不存在 1存在
  int isTableExits(sqlite3 *p, const char *tableName);

  // 创建数据表
  // @param sql 创建表SQL语句
  // @return 0失败
  int createTable(sqlite3 *p, const char *sql);

  // 开启事务
  int transaction(sqlite3 *p);

  // 提交事务
  int commitTransaction(sqlite3 *p);

  // 回滚事务
  int rollbackTransaction(sqlite3 *p);

  // 关闭连接
  void close(sqlite3 *p);

  // 更新数据
  // @param sql 添加/修改/删除SQL语句
  // @return 0失败
  int update(sqlite3 *p, const char *sql);

  // 查询
  // @param 查询SQL语句
  // @return 0失败
  query_result_t* query(sqlite3 *p, const char *sql);

  static Sqlite3helper& Instance(void);


protected:
  ~Sqlite3helper();
private:
  static Sqlite3helper* _pInstance;


};



} // namespace common
} // namespace robot

#endif // ROBOT_COMMON_SQLITE3HELPER_H_
